pub struct AccelerationStructureBindingLayout {
pub vertex_return: bool,
}Expand description
Fields
vertex_return: boolWhether this acceleration structure can be used to create a ray query that has flag vertex return in the shader
If enabled requires wgt::Features::EXPERIMENTAL_RAY_HIT_VERTEX_RETURN