pub struct BindGroupLayoutEntry {
pub binding: u32,
pub visibility: ShaderStages,
pub buffer: Option<BufferBindingLayout>,
pub sampler: Option<SamplerBindingLayout>,
pub texture: Option<TextureBindingLayout>,
pub storage_texture: Option<StorageTextureBindingLayout>,
pub external_texture: Option<ExternalTextureBindingLayout>,
pub acceleration_structure: Option<AccelerationStructureBindingLayout>,
pub count: Option<NonZeroU32>,
}Expand description
Describes a single binding inside a bind group.
Corresponds to WebGPU GPUBindGroupLayoutEntry.
Fields
binding: u32Binding index. Must match shader index and be unique inside a BindGroupLayout. A binding
of index 1, would be described as @group(0) @binding(1) in shaders.
visibility: ShaderStagesWhich shader stages can see this binding.
buffer: Option<BufferBindingLayout>sampler: Option<SamplerBindingLayout>texture: Option<TextureBindingLayout>storage_texture: Option<StorageTextureBindingLayout>external_texture: Option<ExternalTextureBindingLayout>acceleration_structure: Option<AccelerationStructureBindingLayout>count: Option<NonZeroU32>If the binding is an array of multiple resources. Corresponds to binding_array<T> in the shader.
When this is Some the following validation applies:
- Count must be of value 1 or greater, this corresponds to the length of the array of resources that will be bound.
- When
ty == BindingType::Texture,wgt::Features::TEXTURE_BINDING_ARRAYmust be supported. - When
ty == BindingType::Sampler,wgt::Features::TEXTURE_BINDING_ARRAYmust be supported. - When
ty == BindingType::Buffer,wgt::Features::BUFFER_BINDING_ARRAYmust be supported. - When
ty == BindingType::Bufferandty.ty == BufferBindingType::Storage,wgt::Features::STORAGE_RESOURCE_BINDING_ARRAYmust be supported. - When
ty == BindingType::StorageTexture,wgt::Features::STORAGE_RESOURCE_BINDING_ARRAYmust be supported. - When any binding in the group is an array, no
BindingType::Bufferin the group may havehas_dynamic_offset == true - When any binding in the group is an array, no
BindingType::Bufferin the group may havety.ty == BufferBindingType::Uniform. - If
wgt::Features::PARTIALLY_BOUND_BINDING_ARRAYis enabled, the specified count becomes the upper bound instead.