pub struct BufferBindingLayout {
pub ty: BufferBindingType,
pub has_dynamic_offset: bool,
pub min_binding_size: Option<BufferSize>,
}Expand description
A buffer binding.
Corresponds to WebGPU GPUBufferBindingLayout.
Fields
ty: BufferBindingTypeSub-type of the buffer binding.
has_dynamic_offset: boolIndicates that the binding has a dynamic offset.
One offset must be passed to RenderPass::set_bind_group
for each dynamic binding in increasing order of binding number.
min_binding_size: Option<BufferSize>The minimum size for a BufferBinding matching this entry, in bytes.
If this is Some(size):
-
When calling
Device::create_bind_group, the resource at this bind point must be aBindingResource::Bufferwhose effective size is at leastsize. -
When calling
Device::create_render_pipelineorDevice::create_compute_pipeline,sizemust be at least the minimum buffer binding size for the shader module global at this bind point: large enough to hold the global’s value, along with one element of a trailing runtime-sized array, if present.
If this is None:
- Each draw or dispatch command checks that the buffer range at this bind point satisfies the minimum buffer binding size.