StorageTextureBindingLayout

Struct StorageTextureBindingLayout 

pub struct StorageTextureBindingLayout {
    pub access: StorageTextureAccess,
    pub format: TextureFormat,
    pub view_dimension: TextureViewDimension,
}
A storage texture.

Example WGSL syntax:

@group(0) @binding(0)
var my_storage_image: texture_storage_2d<r32float, write>;

Example GLSL syntax:

layout(set=0, binding=0, r32f) writeonly uniform image2D myStorageImage;

Note that the texture format must be specified in the shader, along with the access mode. For WGSL, the format must be one of the enumerants in the list of storage texel formats.

Corresponds to WebGPU GPUStorageTextureBindingLayout.

Fields

access: StorageTextureAccess

Allowed access to this texture.

format: TextureFormat

Format of the texture.

view_dimension: TextureViewDimension

Dimension of the texture view that is going to be sampled.