pub struct TextureBindingLayout {
pub sample_type: TextureSampleType,
pub view_dimension: TextureViewDimension,
pub multisampled: bool,
}Expand description
A texture binding.
Example WGSL syntax:
ⓘ
@group(0) @binding(0)
var t: texture_2d<f32>;Example GLSL syntax:
layout(binding = 0)
uniform texture2D t;Corresponds to WebGPU GPUTextureBindingLayout.
Fields
sample_type: TextureSampleTypeSample type of the texture binding.
view_dimension: TextureViewDimensionDimension of the texture view that is going to be sampled.
multisampled: boolTrue if the texture has a sample count greater than 1. If this is true,
the texture must be declared as texture_multisampled_2d or
texture_depth_multisampled_2d in the shader, and read using textureLoad.