wgpu_render_bundle_insert_debug_marker

Function wgpu_render_bundle_insert_debug_marker 

pub unsafe fn wgpu_render_bundle_insert_debug_marker(
    _bundle: &mut RenderBundleEncoder,
    _label: RawString,
)
Safety

This function is unsafe as there is no guarantee that the given label is a valid null-terminated string.