pub struct ComputePassError {
pub scope: PassErrorScope,
pub(super) inner: ComputePassErrorInner,
}Expand description
Error encountered when performing a compute pass, stored for later reporting when encoding ends.
Fields
scope: PassErrorScopeinner: ComputePassErrorInnerTrait Implementations
Sourceimpl Clone for ComputePassError
impl Clone for ComputePassError
Sourcefn clone(&self) -> ComputePassError
fn clone(&self) -> ComputePassError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputePassError
impl Debug for ComputePassError
Sourceimpl Display for ComputePassError
impl Display for ComputePassError
Sourceimpl Error for ComputePassError
impl Error for ComputePassError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl From<ComputePassError> for CommandEncoderError
impl From<ComputePassError> for CommandEncoderError
Sourcefn from(source: ComputePassError) -> Self
fn from(source: ComputePassError) -> Self
Converts to this type from the input type.
Sourceimpl<E> MapPassErr<ComputePassError> for Ewhere
E: Into<ComputePassErrorInner>,
impl<E> MapPassErr<ComputePassError> for Ewhere
E: Into<ComputePassErrorInner>,
fn map_pass_err(self, scope: PassErrorScope) -> ComputePassError
Sourceimpl WebGpuError for ComputePassError
impl WebGpuError for ComputePassError
Sourcefn webgpu_error_type(&self) -> ErrorType
fn webgpu_error_type(&self) -> ErrorType
Determine the classification of this error as a WebGPU [
ErrorType].Auto Trait Implementations
impl Freeze for ComputePassError
impl !RefUnwindSafe for ComputePassError
impl Send for ComputePassError
impl Sync for ComputePassError
impl Unpin for ComputePassError
impl !UnwindSafe for ComputePassError