DeferredQuerySetResolve

Struct DeferredQuerySetResolve 

pub(crate) struct DeferredQuerySetResolve {
    pub(crate) query_set: Arc<QuerySet>,
    pub(crate) query_set_writes: Option<BitVec>,
    pub(crate) start_query: u32,
    pub(crate) end_query: u32,
    pub(crate) dst_buffer: Arc<Buffer>,
    pub(crate) destination_offset: BufferAddress,
    pub(crate) stride: u64,
    pub(crate) insertion_point: usize,
}

Fields

query_set: Arc<QuerySet>query_set_writes: Option<BitVec>start_query: u32end_query: u32dst_buffer: Arc<Buffer>destination_offset: BufferAddressstride: u64

Bytes per query slot in the destination buffer (accounts for pipeline-statistics element count * QUERY_SIZE).

insertion_point: usize

Index into InnerCommandEncoder::list at which a new command buffer for the resolve operation must be inserted at submit time so that it executes at exactly the position it was recorded.