pub struct ResolvedRenderPassDescriptor<'a> {
pub label: Label<'a>,
pub color_attachments: Cow<'a, [Option<RenderPassColorAttachment<Arc<TextureView>>>]>,
pub depth_stencil_attachment: Option<RenderPassDepthStencilAttachment<Arc<TextureView>>>,
pub timestamp_writes: Option<PassTimestampWrites<Arc<QuerySet>>>,
pub occlusion_query_set: Option<Arc<QuerySet>>,
pub multiview_mask: Option<NonZeroU32>,
}Expand description
Describes the attachments of a render pass.
Fields
label: Label<'a>color_attachments: Cow<'a, [Option<RenderPassColorAttachment<Arc<TextureView>>>]>The color attachments of the render pass.
depth_stencil_attachment: Option<RenderPassDepthStencilAttachment<Arc<TextureView>>>The depth and stencil attachment of the render pass, if any.
timestamp_writes: Option<PassTimestampWrites<Arc<QuerySet>>>Defines where and when timestamp values will be written for this pass.
occlusion_query_set: Option<Arc<QuerySet>>Defines where the occlusion query results will be stored for this pass.
multiview_mask: Option<NonZeroU32>The multiview array layers that will be used