pub struct PassTimestampWrites<QS = Arc<QuerySet>> {
pub query_set: QS,
pub beginning_of_pass_write_index: Option<u32>,
pub end_of_pass_write_index: Option<u32>,
}Expand description
Describes the writing of timestamp values in a render or compute pass. cbindgen:ignore
Fields
query_set: QSThe query set to write the timestamps to.
beginning_of_pass_write_index: Option<u32>The index of the query set at which a start timestamp of this pass is written, if any.
end_of_pass_write_index: Option<u32>The index of the query set at which an end timestamp of this pass is written, if any.