pub(crate) struct CommandIndices {
pub(crate) active_submission_index: FenceValue,
pub(crate) next_acceleration_structure_build_command_index: u64,
}Fields
active_submission_index: FenceValueThe index of the last command submission that was attempted.
Note that fence may never be signalled with this value, if the command
submission failed. If you need to wait for everything running on a
Queue to complete, wait for last_successful_submission_index.
next_acceleration_structure_build_command_index: u64Auto Trait Implementations
impl Freeze for CommandIndices
impl RefUnwindSafe for CommandIndices
impl Send for CommandIndices
impl Sync for CommandIndices
impl Unpin for CommandIndices
impl UnwindSafe for CommandIndices