Marker

Trait Marker 

pub trait Marker: 'static + WasmNotSendSync {
    const TYPE: &'static str;
}
Marker trait used to determine which types uniquely identify a resource.

For example, Device<A> will have the same type of identifier as Device<B> because Device<T> for any T defines the same maker type.

Required Associated Constants

const TYPE: &'static str

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors