pub(crate) struct DrawBatcher {
batches: HashMap<(TrackerIndex, u64, usize), DrawIndirectValidationBatch, BuildHasherDefault<FxHasher>>,
current_dst_entry: Option<CurrentEntry>,
}Expand description
Accumulates all needed data needed to validate indirect draws.
Fields
batches: HashMap<(TrackerIndex, u64, usize), DrawIndirectValidationBatch, BuildHasherDefault<FxHasher>>current_dst_entry: Option<CurrentEntry>Implementations
Sourceimpl DrawBatcher
impl DrawBatcher
pub(crate) fn new() -> Self
Sourcepub(crate) fn add<'a>(
&mut self,
indirect_draw_validation_resources: &'a mut DrawResources,
device: &Device,
src_buffer: &Arc<Buffer>,
offset: u64,
family: DrawCommandFamily,
vertex_or_index_limit: u64,
instance_limit: u64,
) -> Result<(usize, u64), DeviceError>
pub(crate) fn add<'a>( &mut self, indirect_draw_validation_resources: &'a mut DrawResources, device: &Device, src_buffer: &Arc<Buffer>, offset: u64, family: DrawCommandFamily, vertex_or_index_limit: u64, instance_limit: u64, ) -> Result<(usize, u64), DeviceError>
Add an indirect draw to be validated.
Returns the index of the indirect buffer in indirect_draw_validation_resources
and the offset to be used for the draw.