Instance

Struct Instance 

pub struct Instance {
    _name: String,
    instance_per_backend: Vec<(Backend, Box<dyn DynInstance>)>,
    requested_backends: Backends,
    supported_backends: Backends,
    pub flags: InstanceFlags,
    display: Option<Box<dyn WgpuHasDisplayHandle>>,
    devices: InstanceDevices,
}

Fields

_name: Stringinstance_per_backend: Vec<(Backend, Box<dyn DynInstance>)>

List of instances per wgpu-hal backend.

The ordering in this list implies prioritization and needs to be preserved.

requested_backends: Backends

The backends that were requested by the user.

supported_backends: Backends

The backends that we could have attempted to obtain from wgpu-hal — those for which support is compiled in, currently.

The union of this and requested_backends is the set of backends that would be used, independent of whether accessing the drivers/hardware for them succeeds. To obtain the set of backends actually in use by this instance, check instance_per_backend instead.

flags: InstanceFlagsdisplay: Option<Box<dyn WgpuHasDisplayHandle>>

Non-lifetimed [raw_window_handle::DisplayHandle], for keepalive and validation purposes in Self::create_surface().

When used with winit, callers are expected to pass its OwnedDisplayHandle (created from the EventLoop) here.

devices: InstanceDevices

Keeps track of all devices created from this instance, so that they can be polled.

Implementations

Source

impl Instance

pub fn new( name: &str, instance_desc: InstanceDescriptor, telemetry: Option<Telemetry>, ) -> Self

fn try_add_hal<A: Api>( &mut self, _: A, instance_desc: &InstanceDescriptor, telemetry: Option<Telemetry>, )

Helper for Instance::new(); attempts to add a single wgpu-hal backend to this instance.

pub(crate) fn from_hal_instance<A: Api>( name: String, hal_instance: <A as Api>::Instance, ) -> Self

pub fn raw(&self, backend: Backend) -> Option<&dyn DynInstance>

pub unsafe fn as_hal<A: Api>(&self) -> Option<&A::Instance>

Safety
  • The raw instance handle returned must not be manually destroyed.
pub unsafe fn create_surface( &self, display_handle: Option<RawDisplayHandle>, window_handle: RawWindowHandle, ) -> Result<Surface, CreateSurfaceError>

Creates a new surface targeting the given display/window handles.

Internally attempts to create hal surfaces for all enabled backends.

Fails only if creation for surfaces for all enabled backends fails in which case the error for each enabled backend is listed. Vice versa, if creation for any backend succeeds, success is returned. Surface creation errors are logged to the debug log in any case.

Safety
  • display_handle must be a valid object to create a surface upon, falls back to the instance display handle otherwise.
  • window_handle must remain valid as long as the returned SurfaceId is being used.
fn adapter_allowed(&self, raw: &DynExposedAdapter) -> bool

pub fn enumerate_adapters( &self, backends: Backends, apply_limit_buckets: bool, ) -> Vec<Arc<Adapter>>

pub fn request_adapter( &self, desc: &RequestAdapterOptions<&Surface>, backends: Backends, ) -> Result<Arc<Adapter>, RequestAdapterError>

fn adjust_limits_for_indirect_validation(&self, limits: &mut Limits)

This is similar to wgpu-hal’s adjust_raw_limits but tailored to wgpu-core’s constraints.

fn active_backends(&self) -> Backends

pub unsafe fn create_adapter_from_hal( &self, hal_adapter: DynExposedAdapter, ) -> Arc<Adapter>

Create an adapter from a HAL adapter.

The HAL adapter may be obtained e.g. by calling enumerate_adapters on the HAL directly.

If limit bucketing is desired, crate::limits::apply_limit_buckets should be called with the HAL adapter before calling this function.

Safety

hal_adapter must be created from this global internal instance handle.

pub fn poll_all_devices(&self, force_wait: bool) -> Result<bool, WaitIdleError>

Poll all devices on all backends.

This is the implementation of wgpu::Instance::poll_all.

Return all_queue_empty indicating whether there are more queue submissions still in flight.