apply_limit_buckets

Function apply_limit_buckets 

pub fn apply_limit_buckets(raw: DynExposedAdapter) -> Option<DynExposedAdapter>
Apply limit bucketing to the adapter limits and features in raw.

Finds a supported bucket and replaces the capabilities with the set defined by the bucket. If no suitable bucket is found, returns None, but this should only happen with downlevel devices, and attempting to use limit bucketing with downlevel devices is not recommended.