buckets

Function buckets 

pub(crate) fn buckets() -> impl Iterator<Item = &'static Bucket>
Return the defined adapter feature/limit buckets

Buckets are not always subsets of preceding buckets, but enumerate_adapters considers them in the order they are listed here and uses the first bucket satisfied by the device.