pub struct RenderPipelineDescriptor<'a, PLL = PipelineLayoutId, SM = ShaderModuleId, PLC = PipelineCacheId> {
pub label: Label<'a>,
pub layout: Option<PLL>,
pub vertex: VertexState<'a, SM>,
pub primitive: PrimitiveState,
pub depth_stencil: Option<DepthStencilState>,
pub multisample: MultisampleState,
pub fragment: Option<FragmentState<'a, SM>>,
pub multiview_mask: Option<NonZeroU32>,
pub cache: Option<PLC>,
}Expand description
Describes a render (graphics) pipeline.
Fields
label: Label<'a>layout: Option<PLL>The layout of bind groups for this pipeline.
vertex: VertexState<'a, SM>The vertex processing state for this pipeline.
primitive: PrimitiveStateThe properties of the pipeline at the primitive assembly and rasterization level.
depth_stencil: Option<DepthStencilState>The effect of draw calls on the depth and stencil aspects of the output target, if any.
multisample: MultisampleStateThe multi-sampling properties of the pipeline.
fragment: Option<FragmentState<'a, SM>>The fragment processing state for this pipeline.
multiview_mask: Option<NonZeroU32>If the pipeline will be used with a multiview render pass, this indicates how many array layers the attachments will have.
cache: Option<PLC>The pipeline cache to use when creating this pipeline.