pub struct ShaderModule {
pub(crate) state: ResourceState<ShaderModuleState>,
pub(crate) device: Arc<Device>,
pub(crate) label: String,
}Fields
state: ResourceState<ShaderModuleState>device: Arc<Device>label: StringThe label from the descriptor used to create the resource.
Implementations
Sourceimpl ShaderModule
impl ShaderModule
pub(crate) fn state(&self) -> Result<&ShaderModuleState, InvalidResourceError>
pub(crate) fn invalid(device: Arc<Device>, label: String) -> Arc<Self>
Sourcepub(crate) fn finalize_entry_point_name(
&self,
stage: ShaderStage,
entry_point: Option<&str>,
) -> Result<String, StageError>
pub(crate) fn finalize_entry_point_name( &self, stage: ShaderStage, entry_point: Option<&str>, ) -> Result<String, StageError>
Select an entry point name, given an optional name and a shader stage.
This function takes care of turning the Option<&str>
ProgrammableStageDescriptor::entry_point into a specific name.
For non-passthrough shaders, if entry_point is Some, then return it
as a String. Otherwise, return the name of the unique entry point in
self’s module for stage; if there is not exactly one such entry
point, return an error.
The non-passthrough case counts on Interface::check_stage to verify
that an entry point with the given name actually exists.
For passthrough shaders, if entry_point is Some, verify that an
entry point by that name exists (returning an error if not), and return
it as a String. Otherwise, if entry_point is None, then check that
this module has exactly one entry point, and return its name.