pub struct RegistryReport {
pub num_allocated: usize,
pub num_kept_from_user: usize,
pub num_released_from_user: usize,
pub element_size: usize,
}Fields
num_allocated: usizeCount of IDs allocated by IdentityManager
This may be inconsistent with other fields of the report if IDs are allocated or released concurrently with report generation.
num_kept_from_user: usizenum_released_from_user: usizeelement_size: usizeImplementations