Struct wgpu_core::resource::TextureViewDescriptor [−][src]
Describes a TextureView.
Fields
label: Label<'a>Debug label of the texture view. This will show up in graphics debuggers for easy identification.
format: Option<TextureFormat>Format of the texture view, or None for the same format as the texture itself.
At this time, it must be the same the underlying format of the texture.
dimension: Option<TextureViewDimension>The dimension of the texture view. For 1D textures, this must be 1D. For 2D textures it must be one of
D2, D2Array, Cube, and CubeArray. For 3D textures it must be 3D
aspect: TextureAspectAspect of the texture. Color textures must be TextureAspect::All.
base_mip_level: u32Base mip level.
level_count: Option<NonZeroU32>Mip level count.
If Some(count), base_mip_level + count must be less or equal to underlying texture mip count.
If None, considered to include the rest of the mipmap levels, but at least 1 in total.
base_array_layer: u32Base array layer.
array_layer_count: Option<NonZeroU32>Layer count.
If Some(count), base_array_layer + count must be less or equal to the underlying array count.
If None, considered to include the rest of the array layers, but at least 1 in total.