pub struct Snatchable<T> {
value: UnsafeCell<Option<T>>,
}Expand description
A value that is mostly immutable but can be “snatched” if we need to destroy it early.
In order to safely access the underlying data, the device’s global snatchable lock must be taken. To guarantee it, methods take a read or write guard of that special lock.
Fields
value: UnsafeCell<Option<T>>Implementations
Sourceimpl<T> Snatchable<T>
impl<T> Snatchable<T>
pub fn new(val: T) -> Self
pub fn empty() -> Self
Sourcepub fn get<'a>(&'a self, _guard: &'a SnatchGuard<'_>) -> Option<&'a T>
pub fn get<'a>(&'a self, _guard: &'a SnatchGuard<'_>) -> Option<&'a T>
Get read access to the value. Requires a the snatchable lock’s read guard.
Sourcepub fn snatch(&self, _guard: &mut ExclusiveSnatchGuard<'_>) -> Option<T>
pub fn snatch(&self, _guard: &mut ExclusiveSnatchGuard<'_>) -> Option<T>
Take the value. Requires a the snatchable lock’s write guard.