SnatchableInner

Struct SnatchableInner 

pub struct SnatchableInner<T> {
    value: UnsafeCell<T>,
}
A value that is mostly immutable but can be “snatched” if we need to destroy it early.

In order to safely access the underlying data, the device’s global snatchable lock must be taken. To guarantee it, methods take a read or write guard of that special lock.

Fields

value: UnsafeCell<T>

Implementations

Source

impl<T> SnatchableInner<Option<T>>

pub fn new(val: T) -> Self

pub fn empty() -> Self

pub fn get<'a>(&'a self, _guard: &'a SnatchGuard<'_>) -> Option<&'a T>

Get read access to the value. Requires a the snatchable lock’s read guard.

pub fn snatch(&self, _guard: &mut ExclusiveSnatchGuard<'_>) -> Option<T>

Take the value. Requires a the snatchable lock’s write guard.

pub fn take(&mut self) -> Option<T>

Take the value without a guard. This can only be used with exclusive access to self, so it does not require locking.

Typically useful in a drop implementation.