pub(crate) struct Storage<T>where
T: StorageItem,{
pub(crate) map: Vec<Element<T>>,
kind: &'static str,
}Expand description
A table of T values indexed by the id type I.
Storage implements core::ops::Index, accepting Id values as
indices.
The table is represented as a vector indexed by the ids’ index
values, so you should use an id allocator like IdentityManager
that keeps the index values dense and close to zero.
Fields
map: Vec<Element<T>>kind: &'static strImplementations