enum BufferStateProvider<'a> {
Direct {
state: BufferUses,
},
Indirect {
state: &'a [BufferUses],
},
}Expand description
Source of Buffer State.
Variants
Direct
Get a state that was provided directly.
Fields

state: BufferUsesIndirect
Get a state from an an array of states.
Fields

state: &'a [BufferUses]Implementations
Sourceimpl BufferStateProvider<'_>
impl BufferStateProvider<'_>
Sourceunsafe fn get_state(&self, index: usize) -> BufferUses
unsafe fn get_state(&self, index: usize) -> BufferUses
Gets the state from the provider, given a resource ID index.
Safety
Index must be in bounds for the indirect source iff this is in the indirect state.