QuerySetTracker

Struct QuerySetTracker 

pub(crate) struct QuerySetTracker {
    metadata: ResourceMetadata<Arc<QuerySet>>,
    size: usize,
}
A tracker that holds tracks QuerySets.

This is mostly a safe shell around ResourceMetadata

Fields

metadata: ResourceMetadata<Arc<QuerySet>>size: usize

Implementations

Source

impl QuerySetTracker

pub fn new() -> Self

pub fn insert_single(&mut self, resource: Arc<QuerySet>) -> &Arc<QuerySet>

Inserts a single resource into the resource tracker.

Returns a reference to the newly inserted resource. (This allows avoiding a clone/reference count increase in many cases.)

pub fn set_size(&mut self, size: usize)

Sets the size of all the vectors inside the tracker.

Must be called with the highest possible Texture ID before all unsafe functions are called.

fn allow_index(&mut self, index: usize)

Extend the vectors to let the given index be valid.

pub fn contains(&self, query_set: &QuerySet) -> bool

Returns true if the tracker owns the given query set.

pub fn used_resources(&self) -> impl Iterator<Item = &Arc<QuerySet>>