pub(crate) struct BindGroupStates {
pub buffers: BufferBindGroupState,
pub views: TextureViewBindGroupState,
pub external_textures: StatelessTracker<ExternalTexture>,
pub samplers: StatelessTracker<Sampler>,
pub acceleration_structures: StatelessTracker<Tlas>,
}Expand description
All the usages that a bind group contains. The uses are not deduplicated in any way and may include conflicting uses. This is fully compliant by the WebGPU spec.
All bind group states are sorted by their ID so that when adding to a tracker, they are added in the most efficient order possible (ascending order).
Fields
buffers: BufferBindGroupStateviews: TextureViewBindGroupStateexternal_textures: StatelessTracker<ExternalTexture>samplers: StatelessTracker<Sampler>acceleration_structures: StatelessTracker<Tlas>Implementations