skip_barrier_ignore_texture_flags

Function skip_barrier_ignore_texture_flags 

fn skip_barrier_ignore_texture_flags(
    old: TextureUses,
    ordered_uses_mask: TextureUses,
    new: TextureUses,
) -> bool
Returns true if the transition from old to new does not require a barrier, ignoring which read-only aspect was sampled (DEPTH_SAMPLED/STENCIL_SAMPLED).