pub enum BindingLayoutSource {
Derived(Box<ArrayVec<EntryMap, { hal::MAX_BIND_GROUPS }>>),
Provided(Arc<PipelineLayout>),
}Variants
Derived(Box<ArrayVec<EntryMap, { hal::MAX_BIND_GROUPS }>>)
The binding layout is derived from the pipeline layout.
This will be filled in by the shader binding validation, as it iterates the shader’s interfaces.
Provided(Arc<PipelineLayout>)
The binding layout is provided by the user in BGLs.
This will be validated against the shader’s interfaces.
Implementations
Sourceimpl BindingLayoutSource
impl BindingLayoutSource
pub fn new_derived(limits: &Limits) -> Self