check_workgroup_sizes

Function check_workgroup_sizes 

pub(crate) fn check_workgroup_sizes(
    sizes: &[u32; 3],
    per_dimension_limits: &[u32; 3],
    per_dimension_limits_desc: &'static str,
    total_limit: u32,
    total_limit_desc: &'static str,
) -> Result<u32, InvalidWorkgroupSizeError>
Check X/Y/Z workgroup sizes against per-dimension and overall limits.

This function does not check that the sizes are non-zero. In a dispatch, it is legal for the size to be zero. In shader or pipeline creation, it is an error for the size to be zero, and the caller must check that.