validate_color_attachment_bytes_per_sample

Function validate_color_attachment_bytes_per_sample 

pub fn validate_color_attachment_bytes_per_sample(
    attachment_formats: impl IntoIterator<Item = TextureFormat>,
    limit: u32,
) -> Result<(), ColorAttachmentError>
Validate a list of color attachment formats against maxColorAttachmentBytesPerSample.

The color attachments can be from a render pass descriptor or a pipeline descriptor.

Implements https://gpuweb.github.io/gpuweb/#abstract-opdef-calculating-color-attachment-bytes-per-sample.