StageIo

Struct StageIo 

pub struct StageIo {
    pub varyings: FastHashMap<ShaderLocation, InterfaceVar>,
    pub task_payload_size: Option<u32>,
    pub primitive_index: Option<bool>,
    pub immediates: ImmediateUsage,
}
Summary of one shader stage’s outputs, presented as inputs to the next stage.

Each stage in a pipeline produces one of these values, to be validated against the input requirements of the pipeline’s next stage.

Fields

varyings: FastHashMap<ShaderLocation, InterfaceVar>

The prior stage’s Varying::UserDefined outputs.

task_payload_size: Option<u32>

If the prior stage was a task shader, the size of its payload global.

This must match the mesh shader’s payload global.

primitive_index: Option<bool>

If the prior was a mesh shader, whether it output BuiltIn::PrimitiveIndex.

In a mesh pipeline on DX12, the mesh shader and fragment shader must agree on whether PrimitiveIndex is passed between them.

This is None if the prior stage was not a mesh shader.

immediates: ImmediateUsage

The set of immediate data slots the prior stage used.