pub(crate) struct WeakVec<T> {
inner: Vec<Weak<T>>,
}Expand description
An optimized container for Weak references of T that minimizes reallocations by
dropping older elements that no longer have strong references to them.
Fields
inner: Vec<Weak<T>>Implementations