pub(crate) struct BindGroupLayoutState {
pub(crate) raw: RawBindGroupLayout,
pub(crate) origin: Origin,
pub(crate) binding_count_validator: BindingTypeMaxCountValidator,
}Fields
raw: RawBindGroupLayoutorigin: OriginIt is very important that we know if the bind group comes from the BGL pool.
If it does, then we need to remove it from the pool when we drop it.
We cannot unconditionally remove from the pool, as BGLs that don’t come from the pool (derived BGLs) must not be removed.
binding_count_validator: BindingTypeMaxCountValidatorTrait Implementations