pub struct RenderBundle {
pub(crate) state: ResourceState<RenderBundleState>,
base: BasePass<ArcRenderCommand, Infallible>,
pub(super) is_depth_read_only: bool,
pub(super) is_stencil_read_only: bool,
pub(crate) device: Arc<Device>,
pub(super) buffer_memory_init_actions: Vec<BufferInitTrackerAction>,
pub(super) texture_memory_init_actions: Vec<TextureInitTrackerAction>,
label: String,
pub(crate) tracking_data: TrackingData,
discard_hal_labels: bool,
}Expand description
cbindgen:ignore
Fields
state: ResourceState<RenderBundleState>base: BasePass<ArcRenderCommand, Infallible>is_depth_read_only: boolis_stencil_read_only: booldevice: Arc<Device>buffer_memory_init_actions: Vec<BufferInitTrackerAction>texture_memory_init_actions: Vec<TextureInitTrackerAction>label: StringThe label from the descriptor used to create the resource.
tracking_data: TrackingDatadiscard_hal_labels: boolImplementations
Sourceimpl RenderBundle
impl RenderBundle
pub(crate) fn state(&self) -> Result<&RenderBundleState, InvalidResourceError>
pub(crate) fn check_is_valid(&self) -> Result<(), InvalidResourceError>
pub fn invalid( device: Arc<Device>, desc: &RenderBundleDescriptor<'_>, ) -> Arc<Self>
pub(crate) fn to_base_pass( &self, ) -> BasePass<RenderCommand<ArcReferences>, Infallible>
Available on crate feature
trace only.Sourcepub(super) unsafe fn execute(
&self,
raw: &mut dyn DynCommandEncoder,
indirect_draw_validation_resources: &mut DrawResources,
indirect_draw_validation_batcher: &mut DrawBatcher,
snatch_guard: &SnatchGuard<'_>,
) -> Result<(), ExecutionError>
pub(super) unsafe fn execute( &self, raw: &mut dyn DynCommandEncoder, indirect_draw_validation_resources: &mut DrawResources, indirect_draw_validation_batcher: &mut DrawBatcher, snatch_guard: &SnatchGuard<'_>, ) -> Result<(), ExecutionError>
Actually encode the contents into a native command buffer.
This is partially duplicating the logic of render_pass_end.
However the point of this function is to be lighter, since we already had
a chance to go through the commands in render_bundle_encoder_finish.
Note that the function isn’t expected to fail, generally. All the validation has already been done by this point. Execution can still fail if a resource was destroyed or indirect draw validation cannot allocate a buffer.