RenderBundleEncoder

Struct RenderBundleEncoder 

pub struct RenderBundleEncoder { /* private fields */ }

Implementations

Source

impl RenderBundleEncoder

pub fn new( desc: &RenderBundleEncoderDescriptor<'_>, device: Option<&Arc<Device>>, parent_id: DeviceId, ) -> Result<Self, CreateRenderBundleError>

Create a new RenderBundleEncoder.

The underlying device is required to fully validate the descriptor. If the device is not available, some validation will be deferred until finish().

pub fn dummy(parent_id: DeviceId) -> Self

pub fn parent(&self) -> DeviceId

pub fn set_index_buffer( &mut self, buffer: BufferId, index_format: IndexFormat, offset: BufferAddress, size: Option<BufferSize>, ) -> Result<(), PassStateError>

pub fn set_bind_group( &mut self, index: u32, bind_group_id: Option<BindGroupId>, offsets: &[DynamicOffset], ) -> Result<(), PassStateError>

pub fn set_pipeline( &mut self, pipeline_id: RenderPipelineId, ) -> Result<(), PassStateError>

pub fn set_vertex_buffer( &mut self, slot: u32, buffer_id: Option<BufferId>, offset: BufferAddress, size: Option<BufferSize>, ) -> Result<(), PassStateError>

pub fn set_immediates( &mut self, offset: u32, data: &[u8], ) -> Result<(), PassStateError>

pub fn draw( &mut self, vertex_count: u32, instance_count: u32, first_vertex: u32, first_instance: u32, ) -> Result<(), PassStateError>

pub fn draw_indexed( &mut self, index_count: u32, instance_count: u32, first_index: u32, base_vertex: i32, first_instance: u32, ) -> Result<(), PassStateError>

pub fn draw_indirect( &mut self, buffer_id: BufferId, offset: BufferAddress, ) -> Result<(), PassStateError>

pub fn draw_indexed_indirect( &mut self, buffer_id: BufferId, offset: BufferAddress, ) -> Result<(), PassStateError>

pub fn push_debug_group(&mut self, _label: &str) -> Result<(), PassStateError>

pub fn pop_debug_group(&mut self) -> Result<(), PassStateError>

pub fn insert_debug_marker( &mut self, _label: &str, ) -> Result<(), PassStateError>