pub(crate) struct EncoderInFlight {
inner: InnerCommandEncoder,
pub(crate) trackers: Tracker,
pub(crate) temp_resources: Vec<TempResource>,
_indirect_draw_validation_resources: DrawResources,
pub(crate) pending_buffers: HashMap<TrackerIndex, Arc<Buffer>, BuildHasherDefault<FxHasher>>,
pub(crate) pending_textures: HashMap<TrackerIndex, Arc<Texture>, BuildHasherDefault<FxHasher>>,
pub(crate) pending_blas_s: HashMap<TrackerIndex, Arc<Blas>, BuildHasherDefault<FxHasher>>,
}Expand description
A series of raw CommandBuffers that have been submitted to a
queue, and the wgpu_hal::CommandEncoder that built them.
Fields
inner: InnerCommandEncodertrackers: Trackertemp_resources: Vec<TempResource>_indirect_draw_validation_resources: DrawResourcesWe only need to keep these resources alive.
pending_buffers: HashMap<TrackerIndex, Arc<Buffer>, BuildHasherDefault<FxHasher>>These are the buffers that have been tracked by PendingWrites.
pending_textures: HashMap<TrackerIndex, Arc<Texture>, BuildHasherDefault<FxHasher>>These are the textures that have been tracked by PendingWrites.
pending_blas_s: HashMap<TrackerIndex, Arc<Blas>, BuildHasherDefault<FxHasher>>These are the BLASes that have been tracked by PendingWrites.