Marker

Trait Marker 

pub trait Marker: 'static + WasmNotSendSync {
    const TYPE: &'static str;
}
Marker trait used to determine which types uniquely identify a resource.

For example, Device<A> will have the same type of identifier as Device<B> because Device<T> for any T defines the same maker type.

Required Associated Constants

const TYPE: &'static str

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Marker for Adapter

Source

const TYPE: &'static str = "Adapter"

Source

impl Marker for BindGroup

Source

const TYPE: &'static str = "BindGroup"

Source

impl Marker for BindGroupLayout

Source

const TYPE: &'static str = "BindGroupLayout"

Source

impl Marker for Blas

Source

const TYPE: &'static str = "Blas"

Source

impl Marker for Buffer

Source

const TYPE: &'static str = "Buffer"

Source

impl Marker for CommandBuffer

Source

const TYPE: &'static str = "CommandBuffer"

Source

impl Marker for CommandEncoder

Source

const TYPE: &'static str = "CommandEncoder"

Source

impl Marker for ComputePassEncoder

Source

const TYPE: &'static str = "ComputePassEncoder"

Source

impl Marker for ComputePipeline

Source

const TYPE: &'static str = "ComputePipeline"

Source

impl Marker for Device

Source

const TYPE: &'static str = "Device"

Source

impl Marker for ExternalTexture

Source

const TYPE: &'static str = "ExternalTexture"

Source

impl Marker for PipelineCache

Source

const TYPE: &'static str = "PipelineCache"

Source

impl Marker for PipelineLayout

Source

const TYPE: &'static str = "PipelineLayout"

Source

impl Marker for QuerySet

Source

const TYPE: &'static str = "QuerySet"

Source

impl Marker for Queue

Source

const TYPE: &'static str = "Queue"

Source

impl Marker for RenderBundle

Source

const TYPE: &'static str = "RenderBundle"

Source

impl Marker for RenderBundleEncoder

Source

const TYPE: &'static str = "RenderBundleEncoder"

Source

impl Marker for RenderPassEncoder

Source

const TYPE: &'static str = "RenderPassEncoder"

Source

impl Marker for RenderPipeline

Source

const TYPE: &'static str = "RenderPipeline"

Source

impl Marker for Sampler

Source

const TYPE: &'static str = "Sampler"

Source

impl Marker for ShaderModule

Source

const TYPE: &'static str = "ShaderModule"

Source

impl Marker for StagingBuffer

Source

const TYPE: &'static str = "StagingBuffer"

Source

impl Marker for Surface

Source

const TYPE: &'static str = "Surface"

Source

impl Marker for Texture

Source

const TYPE: &'static str = "Texture"

Source

impl Marker for TextureView

Source

const TYPE: &'static str = "TextureView"

Source

impl Marker for Tlas

Source

const TYPE: &'static str = "Tlas"