pub(crate) trait ResourceUses:
Debug
+ BitAnd<Output = Self>
+ BitOr<Output = Self>
+ PartialEq
+ Sized
+ Copy {
type Selector: Debug;
const EXCLUSIVE: Self;
// Required methods
fn bits(self) -> u32;
fn any_exclusive(self) -> bool;
// Provided method
fn is_invalid(self) -> bool { ... }
}Expand description
The uses that a resource or subresource can be in.
Required Associated Constants
Required Associated Types
Required Methods
Sourcefn any_exclusive(self) -> bool
fn any_exclusive(self) -> bool
Returns true if any of the uses are exclusive.
Provided Methods
Sourcefn is_invalid(self) -> bool
fn is_invalid(self) -> bool
Returns true if the given states violates the usage scope rule of any(inclusive) XOR one(exclusive)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.