pub(crate) trait ResourceUses:
Debug
+ BitAnd<Output = Self>
+ BitOr<Output = Self>
+ PartialEq
+ Sized
+ Copy {
type Selector: Debug;
const EXCLUSIVE: Self;
// Required methods
fn bits(self) -> u16;
fn any_exclusive(self) -> bool;
}Expand description
The uses that a resource or subresource can be in.
Required Associated Constants
Required Associated Types
Required Methods
Sourcefn any_exclusive(self) -> bool
fn any_exclusive(self) -> bool
Returns true if any of the uses are exclusive.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.