Module validation

Module validation 

Modules

shader_io_deductions

Structs

Interface
InterfaceVar
NumericType
StageIo

Enums

BindingError
BindingLayoutSource
BindingTypeName
FilteringError
InputError
ShaderStageForValidation
StageError
Errors produced when validating a programmable stage of a pipeline.

Functions

check_texture_format
Return true if the fragment format is covered by the provided output.
map_storage_format_from_naga
Map a naga::StorageFormat to the corresponding wgt::TextureFormat.
map_storage_format_to_naga
Map a wgt::TextureFormat to the corresponding naga::StorageFormat, if any.
validate_color_attachment_bytes_per_sample
Validate a list of color attachment formats against maxColorAttachmentBytesPerSample.