pub struct StageIo {
pub varyings: HashMap<ShaderLocation, InterfaceVar, BuildHasherDefault<FxHasher>>,
pub task_payload_size: Option<u32>,
pub primitive_index: Option<bool>,
}Fields
varyings: HashMap<ShaderLocation, InterfaceVar, BuildHasherDefault<FxHasher>>task_payload_size: Option<u32>This must match between mesh & task shaders
primitive_index: Option<bool>Fragment shaders cannot input primitive index on mesh shaders that don’t output it on DX12. Therefore, we track between shader stages if primitive index is written (or if vertex shader is used).
This is Some if it was a mesh shader.