pub(crate) struct WorkgroupSizeCheck<'a> {
pub dimensions: &'a [u32; 3],
pub per_dimension_limits: &'a [u32; 3],
pub per_dimension_limits_desc: &'static str,
pub total_limit: u32,
pub total_limit_desc: &'static str,
}Expand description
A helper type for avoiding argument order mistakes when calling
Self::check_and_compute_total_invocations.
Fields
dimensions: &'a [u32; 3]per_dimension_limits: &'a [u32; 3]per_dimension_limits_desc: &'static strtotal_limit: u32total_limit_desc: &'static strImplementations
Sourceimpl WorkgroupSizeCheck<'_>
impl WorkgroupSizeCheck<'_>
Sourcepub(crate) fn check_and_compute_total_invocations(
self,
) -> Result<u32, InvalidWorkgroupSizeError>
pub(crate) fn check_and_compute_total_invocations( self, ) -> Result<u32, InvalidWorkgroupSizeError>
Check X/Y/Z workgroup sizes against per-dimension and overall limits.
This function does not check that the sizes are non-zero. In a dispatch, it is legal for the size to be zero. In shader or pipeline creation, it is an error for the size to be zero, and the caller must check that.